==> 1.7.2.zip: harbour-sailotp/translations/harbour-sailotp-de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/pages/About.qml" line="75"/>
        <source>A Simple Sailfish OTP Generator
(RFC 6238/4226 compatible)</source>
        <translation>Ein einfacher Sailfish OTP-Generator
(RFC 6238/4226-kompatibel)</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="84"/>
        <source>Copyright: Stefan Brand
License: BSD (3-clause)</source>
        <translation>Copyright: Stefan Brand
Lizenz: BSD (3-Klausel)</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="110"/>
        <source>SailOTP uses the following third party libs:</source>
        <translation>SailOTP verwendet folgende externe Bibliotheken:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="121"/>
        <source>Contributors:</source>
        <translation>Mitwirkende:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="121"/>
        <source>Support</source>
        <translation>Unterstützung</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="132"/>
        <source>Translators:</source>
        <translation>Übersetzer:</translation>
    </message>
</context>
<context>
    <name>AddOTP</name>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="69"/>
        <source>Show QR-Code</source>
        <translation>QR-Code anzeigen</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="72"/>
        <source>Can&apos;t create QR-Code from incomplete settings!</source>
        <translation>Ein QR-Code kann nur mit vollständigen Einstellungen erzeugt werden!</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="86"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="86"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="91"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="93"/>
        <source>Time-based (TOTP)</source>
        <translation>Zeitbasiert (TOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="94"/>
        <source>Counter-based (HOTP)</source>
        <translation>Zählerbasiert (HOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="95"/>
        <source>Steam Guard</source>
        <translation>Steam Guard</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="101"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="102"/>
        <source>Title for the OTP</source>
        <translation>Titel für das Token</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="114"/>
        <source>Secret (at least 16 characters)</source>
        <translation>Schlüssel (mindestens 16 Zeichen)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="116"/>
        <source>Secret OTP Key</source>
        <translation>Geheimer Schlüssel</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="128"/>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="130"/>
        <source>Length of the Token</source>
        <translation>Länge des Tokens</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="142"/>
        <location filename="../qml/pages/AddOTP.qml" line="144"/>
        <source>Time Derivation (Seconds)</source>
        <translation>Zeitabweichung (Sekunden)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="156"/>
        <source>Next Counter Value</source>
        <translation>Nächster Zählerwert</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="158"/>
        <source>Next Value of the Counter</source>
        <translation>Nächster Wert für den Zähler</translation>
    </message>
</context>
<context>
    <name>ExportPage</name>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="63"/>
        <source>File already exists, choose &quot;Overwrite existing&quot; to overwrite it.</source>
        <translation>Datei existiert, aktiviere &quot;Existierende überschreiben&quot; um sie zu ersetzen.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="72"/>
        <source>Given file does not exist!</source>
        <translation>Gewählte Datei existiert nicht!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="114"/>
        <source>Filename</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to import</source>
        <translation>Aus Datei importieren</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to export</source>
        <translation>In Datei exportieren</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="128"/>
        <source>Overwrite existing</source>
        <translation>Existierende überschreiben</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="134"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="135"/>
        <source>Password for the file</source>
        <translation>Passwort für die Datei</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords don&apos;t match!</source>
        <translation>Passwörter nicht identisch!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords match!</source>
        <translation>Passwörter identisch!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="149"/>
        <source>Repeated Password for the file</source>
        <translation>Passwort wiederholen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="173"/>
        <source>Here you can Import Tokens from a file. Put in the file location and the password you used on export. Pull left to start the import.</source>
        <translation>Hier können Tokens aus einer Datei importiert werden. Gib die Datei und das beim Export gewählte Passwort ein. Nach links ziehen um zu starten.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>Here you can export Tokens to a file. The exported file will be encrypted with AES-256-CBC and Base64 encoded. Choose a strong password, the file will contain the secrets used to generate the Tokens for your accounts. Pull left to start the export.</source>
        <translation>Hier können Tokens in eine Datei exportiert werden. Die Datei wird mit AES-256-CBC verschlüsselt und Base64-kodiert. Wähle ein starkes Passwort, die Datei enthält die geheimen Schlüssel zur Erzeugung der Tokens für deine Accounts. Nach links ziehen um zu starten.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>To view the content of the export file outside of SailOTP use the following openssl command:</source>
        <translation>Mit folgendem Openssl-Befehl kann der Inhalt der Exportdatei außerhalb von SailOTP angezeigt werden:</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="211"/>
        <source>Error writing to file </source>
        <translation>Fehler beim Schreiben der Datei</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="213"/>
        <source>Token Database exported to </source>
        <translation>Datenbank exportiert nach </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="216"/>
        <source>Could not encrypt tokens. Error: </source>
        <translation>Fehler beim Verschlüsseln. Fehler: </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="219"/>
        <source>Could not read tokens from Database</source>
        <translation>Datenbank konnte nicht gelesen werden</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="230"/>
        <source>Tokens imported from </source>
        <translation>Tokens importiert aus </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="235"/>
        <source>Unable to decrypt file, did you use the right password?</source>
        <translation>Fehler beim entschlüsseln, falsches Passwort?</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="238"/>
        <source>Could not read from file </source>
        <translation>Datei konnte nicht gelesen werden</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../qml/pages/MainView.qml" line="96"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="100"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="105"/>
        <source>Export / Import</source>
        <translation>Export / Import</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="109"/>
        <source>Add Token</source>
        <translation>Token hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="139"/>
        <source>Nothing here</source>
        <translation>Hier ist nichts</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="140"/>
        <source>Pull down to add a OTP</source>
        <translation>Nach unten ziehen zum hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="151"/>
        <source>Deleting</source>
        <translation>Lösche</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="167"/>
        <source>Token for </source>
        <translation>Token für </translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="167"/>
        <source> copied to clipboard</source>
        <translation> kopiert</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="235"/>
        <source>Move up</source>
        <translation>Nach oben</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="240"/>
        <source>Move down</source>
        <translation>Nach unten</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="245"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="251"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>QRPage</name>
    <message>
        <location filename="../qml/pages/QRPage.qml" line="74"/>
        <source>Can&apos;t create QR-Code from incomplete settings!</source>
        <translation>Ein QR-Code kann nur mit vollständigen Einstellungen erzeugt werden!</translation>
    </message>
</context>
<context>
    <name>ScanOTP</name>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="54"/>
        <source>Can&apos;t access temporary directory</source>
        <translation>Kein Zugriff auf temporäres Verzeichnis.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="64"/>
        <source>Add manually</source>
        <translation>Manuell hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scan Code</source>
        <translation>Code scannen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scanning...</source>
        <translation>scanne...</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="101"/>
        <source>No valid Token data found.</source>
        <translation>Kein gültiges Token gefunden.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="142"/>
        <source>Tap the picture to start / stop scanning. Pull down to add Token manually.</source>
        <translation>Vorschau antippen um den Scan zu starten / zu stoppen. Nach unten ziehen um manuell hinzu zu fügen.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="50"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="52"/>
        <source>Behaviour</source>
        <translation>Verhalten</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Show Token as QRCode on Tap</source>
        <translation>Token bei antippen als QR-Code zeigen</translation>
    </message>
</context>
</TS>

==> 1.9.2.zip: harbour-sailotp/translations/harbour-sailotp-de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/pages/About.qml" line="70"/>
        <source>A simple Sailfish OTP generator</source>
        <translation>Ein einfacher Sailfish OTP Generator</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="78"/>
        <source>(RFC 6238/4226 compatible)</source>
        <translation>(RFC 6238/4226 kompatibel)</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="87"/>
        <source>Online Manual</source>
        <translation>Onlinehilfe</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="94"/>
        <source>Source Code &amp; Issue Tracker</source>
        <translation>Sourcecode &amp; Bugtracker</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="111"/>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="120"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="120"/>
        <source>BSD (3-clause)</source>
        <translation>BSD (3-Klausel)</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="139"/>
        <source>SteamGuard support</source>
        <translation>Steamguard-Unterstützung</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="146"/>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="240"/>
        <source>SailOTP uses the following third party libs:</source>
        <translation>SailOTP verwendet folgende externe Bibliotheken:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="133"/>
        <source>Contributors:</source>
        <translation>Mitwirkende:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="162"/>
        <source>Translators:</source>
        <translation>Übersetzer:</translation>
    </message>
</context>
<context>
    <name>AddOTP</name>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="69"/>
        <source>Show QR-Code</source>
        <translation>QR-Code Anzeigen</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="72"/>
        <location filename="../qml/pages/AddOTP.qml" line="85"/>
        <source>Can&apos;t create QR-Code from incomplete settings!</source>
        <translation>Ein QR-Code kann nur mit vollständigen Einstellungen erzeugt werden!</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="98"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="98"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="103"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="105"/>
        <source>Time-based (TOTP)</source>
        <translation>Zeitbasiert (TOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="106"/>
        <source>Counter-based (HOTP)</source>
        <translation>Zählerbasiert (HOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="107"/>
        <source>Steam Guard</source>
        <translation>Steam Guard</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="113"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="114"/>
        <source>Title for the OTP</source>
        <translation>Titel für das Token</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="126"/>
        <source>Secret (at least 16 characters)</source>
        <translation>Schlüssel (mindestens 16 Zeichen)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="128"/>
        <source>Secret OTP Key</source>
        <translation>Geheimer Schlüssel</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="142"/>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="144"/>
        <source>Length of the Token</source>
        <translation>Länge des Tokens</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="156"/>
        <location filename="../qml/pages/AddOTP.qml" line="158"/>
        <source>Time Derivation (Seconds)</source>
        <translation>Zeitabweichung (Sekunden)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="170"/>
        <source>Next Counter Value</source>
        <translation>Nächster Zählerwert</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="172"/>
        <source>Next Value of the Counter</source>
        <translation>Nächster Wert für den Zähler</translation>
    </message>
</context>
<context>
    <name>ExportPage</name>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="63"/>
        <source>File already exists, choose &quot;Overwrite existing&quot; to overwrite it.</source>
        <translation>Datei existiert, aktiviere &quot;Existierende überschreiben&quot; um sie zu ersetzen.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="72"/>
        <source>Given file does not exist!</source>
        <translation>Gewählte Datei existiert nicht!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="114"/>
        <source>Filename</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to import</source>
        <translation>Aus Datei importieren</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to export</source>
        <translation>In Datei exportieren</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="128"/>
        <source>Overwrite existing</source>
        <translation>Existierende überschreiben</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="134"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="135"/>
        <source>Password for the file</source>
        <translation>Passwort für die Datei</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords don&apos;t match!</source>
        <translation>Passwörter nicht identisch!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords match!</source>
        <translation>Passwörter identisch!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="149"/>
        <source>Repeated Password for the file</source>
        <translation>Passwort wiederholen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="173"/>
        <source>Here you can Import Tokens from a file. Put in the file location and the password you used on export. Pull left to start the import.</source>
        <translation>Hier können Tokens aus einer Datei importiert werden. Gib die Datei und das beim Export gewählte Passwort ein. Nach links ziehen um zu starten.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>Here you can export Tokens to a file. The exported file will be encrypted with AES-256-CBC and Base64 encoded. Choose a strong password, the file will contain the secrets used to generate the Tokens for your accounts. Pull left to start the export.</source>
        <translation>Hier können Tokens in eine Datei exportiert werden. Die Datei wird mit AES-256-CBC verschlüsselt und Base64-kodiert. Wähle ein starkes Passwort, die Datei enthält die geheimen Schlüssel zur Erzeugung der Tokens für deine Accounts. Nach links ziehen um zu starten.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>To view the content of the export file outside of SailOTP use the following openssl command:</source>
        <translation>Mit folgendem Openssl-Befehl kann der Inhalt der Exportdatei außerhalb von SailOTP angezeigt werden:</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="211"/>
        <source>Error writing to file </source>
        <translation>Fehler beim Schreiben der Datei</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="213"/>
        <source>Token Database exported to </source>
        <translation>Datenbank exportiert nach </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="216"/>
        <source>Could not encrypt tokens. Error: </source>
        <translation>Fehler beim Verschlüsseln. Fehler: </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="219"/>
        <source>Could not read tokens from Database</source>
        <translation>Datenbank konnte nicht gelesen werden</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="230"/>
        <source>Tokens imported from </source>
        <translation>Tokens importiert aus </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="235"/>
        <source>Unable to decrypt file, did you use the right password?</source>
        <translation>Fehler beim entschlüsseln, falsches Passwort?</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="238"/>
        <source>Could not read from file </source>
        <translation>Datei konnte nicht gelesen werden</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../qml/pages/MainView.qml" line="109"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="113"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="118"/>
        <source>Export / Import</source>
        <translation>Export / Import</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="122"/>
        <source>Add Token</source>
        <translation>Token hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="136"/>
        <source>Nothing here</source>
        <translation>Hier ist nichts</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="137"/>
        <source>Pull down to add a OTP</source>
        <translation>Nach unten ziehen zum Hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="178"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="198"/>
        <source>Deleting</source>
        <translation>Lösche </translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="219"/>
        <location filename="../qml/pages/MainView.qml" line="293"/>
        <source>Token for </source>
        <translation>Token für </translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="219"/>
        <location filename="../qml/pages/MainView.qml" line="293"/>
        <source> copied to clipboard</source>
        <translation> in die Zwischenablage kopiert</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="289"/>
        <source>Copy to Clipboard</source>
        <translation>In die Zwischenablage</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="297"/>
        <source>Show Token as QR-Code</source>
        <translation>Als QR-Code Zeigen</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="302"/>
        <source>Move up</source>
        <translation>Nach oben</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="307"/>
        <source>Move down</source>
        <translation>Nach unten</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="312"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="318"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>QRPage</name>
    <message>
        <location filename="../qml/pages/QRPage.qml" line="74"/>
        <source>Can&apos;t create QR-Code from an empty String</source>
        <translation>QR-Code kann nciht aus leerer Eingabe erzeugt werden</translation>
    </message>
</context>
<context>
    <name>ScanOTP</name>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="54"/>
        <source>Can&apos;t access temporary directory</source>
        <translation>Kein Zugriff auf temporäres Verzeichnis.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="64"/>
        <source>Add manually</source>
        <translation>Manuell hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scan Code</source>
        <translation>Code scannen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scanning...</source>
        <translation>scanne...</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="96"/>
        <source>No valid Token data found.</source>
        <translation>Kein gültiges Token gefunden.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="137"/>
        <source>Tap the picture to start / stop scanning. Pull down to add Token manually.</source>
        <translation>Vorschau antippen um den Scan zu starten / zu stoppen. Nach unten ziehen um manuell hinzu zu fügen.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="50"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="52"/>
        <source>Behaviour</source>
        <translation>Verhalten</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Show Token as QR on Tap</source>
        <translation>Zeige QR-Code beim Antippen</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="68"/>
        <source>Hide Tokens and Reveal on Tap</source>
        <translation>Token erst durch Antippen zeigen</translation>
    </message>
</context>
</TS>
